@@ -11,8 +11,10 @@ class payUnit:
     def __init__(self,data):      
         self.config_data = data
 
-    def createPayment(self,amount): 
-
+    def makePayment(self,amount): 
+        if(amount <= 0):
+            return {"message":"Invalid transaction amount","status":False}
+            
         user_api = self.config_data["user_api"]
         password_api = str(self.config_data["password_api"])
         api_key = str(self.config_data["api_key"])      
